.. _index:

hgvs
!!!!

.. include:: description.txt

`Source <https://github.com/biocommons/hgvs>`_ | `Documentation <http://hgvs.readthedocs.org/>`_ | `Discuss <https://groups.google.com/forum/#!forum/hgvs-discuss>`_ | `Issues`_


Contents
@@@@@@@@

.. toctree::
   :maxdepth: 2

   intro

   quick_start

   installation
   key_concepts
   examples

   reference
   privacy

   contributing
   getting_help
   faq

   changelog/index

   license


Indices and tables
@@@@@@@@@@@@@@@@@@

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
